library cafebazaar_flutter;

import 'dart:async';
import 'package:flutter/services.dart';

part 'src/iap/in_app_purchase.dart';
part 'src/iap/purchase_info.dart';

class CafebazaarFlutter {
  static const String _NAMESPACE = 'cafebazaar_flutter';

  static const MethodChannel _methodChannel =
      const MethodChannel('${CafebazaarFlutter._NAMESPACE}/methods');

  CafebazaarFlutter._();

  static CafebazaarFlutter _instance = CafebazaarFlutter._();
  static CafebazaarFlutter get instance => _instance;

  /// Initialization of InAppPurchase
  InAppPurchase inAppPurchase(String publicKey) => InAppPurchase._(publicKey);

  /// Get latest version of app in cafeBazaar
  FutureOr<int?> getLatestVersion() => _methodChannel.invokeMethod('getLatestVersion');

  /// Check user isLoggedIn cafeBazaar
  FutureOr<bool?> isLoggedIn() => _methodChannel.invokeMethod('isLoggedIn');

  /// Open cafeBazaar login page
  FutureOr openLogin() => _methodChannel.invokeMethod('openLogin');

  /// Open detail page of app in cafeBazaar
  FutureOr openDetail([String? packageName]) =>
      _methodChannel.invokeMethod('openDetail', {
        'packageName': packageName,
      });

  /// Open comment form of app in cafeBazaar
  FutureOr openCommentForm([String? packageName]) =>
      _methodChannel.invokeMethod('openCommentForm', {
        'packageName': packageName,
      });

  /// Open developer app list In cafeBazaar
  FutureOr openDeveloperPage(String developerId) =>
      _methodChannel.invokeMethod('openDeveloperPage', {
        'developerId': developerId,
      });
}
